@@ -1,9 +1,3 @@
-from __future__ import annotations
-
-__all__ = (
-    'Client',
-)
-
 #  The MIT License (MIT)
 #  Copyright (c) 2021-present foxwhite25
 #
@@ -24,16 +18,24 @@ __all__ = (
 #  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
+from __future__ import annotations
+
+__all__ = (
+    'Client',
+)
+
 
 import asyncio
 import logging
 import signal
 import sys
 import traceback
-from typing import Optional, Any, Dict, Callable, List, Tuple, Coroutine, TypeVar, Generator, Union, TYPE_CHECKING
+from typing import Optional, Any, Dict, Callable, List, Tuple, Coroutine, TypeVar, Generator, Union, TYPE_CHECKING, \
+    Sequence
 
 import aiohttp
 
+from . import utils
 from .backoff import ExponentialBackoff
 from .error import HTTPException, GatewayNotFound, ConnectionClosed
 from .state import ConnectionState
@@ -46,7 +48,7 @@ from .user import ClientUser, User
 if TYPE_CHECKING:
     from .abc import GuildChannel
     from .member import Member
-
+    from .message import Message
 
 URL = r'https://api.sgroup.qq.com'
 _log = logging.getLogger(__name__)
@@ -290,6 +292,12 @@ class Client:
         """List[:class:`.Guild`]: 连接的客户端所属的频道。"""
         return self._connection.guilds
 
+    @property
+    def cached_messages(self) -> Sequence[Message]:
+        """Sequence[:class:`.Message`]: 连接的客户端已缓存的消息的只读列表。
+        """
+        return utils.SequenceProxy(self._connection._messages or [])
+
     def get_guild(self, id: int, /) -> Optional[Guild]:
         """返回具有给定 ID 的频道。
 
